@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 """
-http.py
+response.py
 
 A collection of Response classes for pyroutes
 """
@@ -78,7 +78,7 @@ class Response(object):
         self.headers = []
         if default_content_header and 'Content-Type' not in header_names:
             # Whether or not this is a safe operation may be python/wsgiref
-            # version dependent. Should be tested and documented.
+            # version dependent. TODO: Should be tested and documented.
             self.headers.append(('Content-Type', settings.DEFAULT_CONTENT_TYPE))
         if not headers is None:
             self.headers += headers
@@ -93,12 +93,23 @@ class Response(object):
 class Redirect(Response):
     """
     A redirect shortcut class for redirection responses
+    This class can make two types of redirects:
+     1. Absolute path redirects: When you want do redirect to outside your application.
+     2. Root App relative redirect: If you want your redirection relative to the root application path
+
+     e.g If Your application is deployed on http://server/apps/myapp, a Redirect("/some/path")
+       actually will generate a redirect to "/apps/myapp/some/path".
+       And a Redirect("/some/path", absolute_path=True) will return a redirect to "/some/path".
     """
 
-    def __init__(self, location):
+    def __init__(self, location, absolute_path=False):
         self.content = "redirect"
+
+        if location.startswith('/') and not absolute_path:
+            location = '/'.join([settings.SITE_ROOT.rstrip('/'), location.lstrip('/')])
+
         self.headers = [('Location', location)]
-        self.status_code = "302 See Other"
+        self.status_code = '302 %s' % responses[302]
         self.cookies = ResponseCookieHandler()
 
 class HttpException(Exception):
@@ -109,11 +120,7 @@ class HttpException(Exception):
 
         self.template_variable = 'TEMPLATE_%d' % self.code
         self.template_filename = '%d.xml' % self.code
-        self.status_code = {
-            403: '403 Forbidden',
-            404: '404 Not Found',
-            500: '500 Server Error'
-        }[self.code]
+        self.status_code = "%d %s" % (self.code, responses[self.code])
 
         if hasattr(settings, self.template_variable):
             if hasattr(settings, 'CUSTOM_BASE_TEMPLATE'):
