@@ -2,7 +2,7 @@ import sys
 import traceback
 
 from pyroutes import settings
-from pyroutes.http.response import Http404, Http500
+from pyroutes.http.response import HttpException, Http404, Http500
 
 class NotFoundMiddleware(object):
     def __init__(self, passthrough):
@@ -25,13 +25,18 @@ class ErrorHandlerMiddleware(object):
     def __call__(self, request):
         try:
             self.response = self.passthrough(request)
+        except HttpException, exception:
+            return exception.get_response(request.ENV['PATH_INFO'])
         except Exception, exception:
             error = Http500()
+
+            exception_type, exception_value, exception_trace = sys.exc_info()
+            trace = "".join(traceback.format_exception(exception_type,
+                                                exception_value,
+                                                exception_trace))
+            sys.stderr.write(trace)
+
             if settings.DEBUG:
-                exception_type, exception_value, exception_trace = sys.exc_info()
-                trace = "".join(traceback.format_exception(exception_type,
-                                                    exception_value,
-                                                    exception_trace))
                 self.response = error.get_response(
                         request.ENV['PATH_INFO'],
                         description="%s: %s" % (exception.__class__.__name__,
@@ -39,7 +44,7 @@ class ErrorHandlerMiddleware(object):
                         traceback=trace)
             else:
                 self.response = error.get_response(request.ENV['PATH_INFO'])
-        
+
         return self.response
 
 class HandlerDidNotReturnReponseObjectException(Exception):
