@@ -1,9 +1,12 @@
 import os
 
-# Used for importing settings, and defining default settings
-#
-# Override per project settings in pyroutes_settings.py in
-# your project folder
+"""
+Module pyroutes.settings
+Used for importing settings, and defining default settings
+
+Override per project settings in pyroutes_settings.py in
+your project folder
+"""
 
 # Default template dir, relative to this imported __file__
 BUILTIN_TEMPLATES_DIR = os.path.join(
@@ -18,17 +21,17 @@ DEBUG = False
 # For setting the default content type
 DEFAULT_CONTENT_TYPE = 'text/html; charset=utf-8'
 
-# Secret key for crypto. CHANGE THIS IS pyroutes_settings!
-SECRET_KEY = 'asdfnaj2308sydfahli37flas36al9gaiufw'
+# Secret key for crypto. SET THIS in pyroutes_settings!
+SECRET_KEY = None
 
 # Location for templates. Used by TemplateRenderer
 TEMPLATE_DIR = None # /foo/bar/templates/
 
 # Middleware
-MIDDLEWARE = [
+MIDDLEWARE = (
     'pyroutes.middleware.errors.NotFoundMiddleware',
     'pyroutes.middleware.errors.ErrorHandlerMiddleware',
-]
+)
 
 # Attempt to get custom settings. Not obligatory.
 try:
