@@ -36,7 +36,7 @@ def devserver(application, port=8001, address='0.0.0.0', auto_reload=True):
     else:
         server_thread()
 
-def fileserver(request):
+def fileserver(request, *path_list):
     """
     Simple file server for development servers. Not for use in production
     environments. Typical usage::
@@ -54,8 +54,7 @@ def fileserver(request):
         files will be looked for in '/srv/media/files'
     """
 
-    path = request.ENV['PATH_INFO']
-    path_list = path.lstrip('/').split('/')
+    path_list = request.matched_path.strip('/').split('/') + list(path_list)
 
     # Do not expose entire file system
     if '..' in path_list:
@@ -73,20 +72,19 @@ def fileserver(request):
         raise Http403
 
     modified = datetime.datetime.fromtimestamp(os.path.getmtime(path))
+    modified = datetime.datetime.strftime(modified, "%a, %d %b %Y %H:%M:%S")
     if 'HTTP_IF_MODIFIED_SINCE' in request.ENV:
-        modified = datetime.datetime.strftime(modified, "%a, %d %b %Y %H:%M:%S")
         if request.ENV.get('HTTP_IF_MODIFIED_SINCE') == modified:
             return Response(status_code='304 Not Modified',
                     default_content_header=False)
-    modified = datetime.datetime.strftime(modified, "%a, %d %b %Y %H:%M:%S")
 
     headers = [
         ('Last-Modified', modified),
     ]
 
     if os.path.isdir(path):
-        if not path.endswith('/'):
-            return Redirect(path + '/')
+        if not request.ENV['PATH_INFO'].endswith('/'):
+            return Redirect(path.lstrip('.') + '/')
 
         listing = []
         files = []
@@ -101,7 +99,7 @@ def fileserver(request):
 
         template_data = {
             'file_list': listing,
-            'title': 'Listing of %s' % path
+            'title': 'Listing of %s' % path.lstrip('.')
         }
 
         templaterenderer = TemplateRenderer(
